<?php
/**
 * A command for the 'main' routine
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class HubHtmlIndexCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance	An instance of a command resolver class
	 * @return	$commandInstance	An instance a prepared command class
	 */
	public static final function createHubHtmlIndexCommand (CommandResolver $resolverInstance) {
		// Get new instance
		$commandInstance = new HubHtmlIndexCommand();

		// Set the application instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the given command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// This command doesn't handle any POST requests, so only handle get request
		if ($requestInstance->isPostRequestMethod()) {
			// Don't handle this here
			$response->sendRequestMethodNotAllowed();

			// Bail out
			exit();
		} // END - if

		/*
		 * This is a generic HTML request, this means that a regular page with
		 * header, menu, content and footer shall be send to the client.
		 */
		$this->sendGenericGetResponse($requestInstance, $responseInstance);
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 * @todo	0% done
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Add pre filters
		//$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('node_php_requirements_filter'));
	}
}

// [EOF]
?>
