<?php
/**
 * A console controller for the crawler program.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007 - 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class HubConsoleFuseController extends BaseController implements Controller {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Init additional filter chains
		foreach (array('bootstrap','shutdown') as $filterChain) {
			$this->initFilterChain($filterChain);
		} // END - foreach
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance		An instance of a command resolver class
	 * @return	$controllerInstance		A prepared instance of this class
	 */
	public static final function createHubConsoleFuseController (CommandResolver $resolverInstance) {
		// Create the instance
		$controllerInstance = new HubConsoleFuseController();

		// Set the command resolver
		$controllerInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $controllerInstance;
	}

	/**
	 * Handles the given request and response
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @param	$responseInstance	An instance of a response class
	 * @return	void
	 */
	public function handleRequest (Requestable $requestInstance, Responseable $responseInstance) {
		// Get the command instance from the resolver by sending a request instance to the resolver
		$commandInstance = $this->getResolverInstance()->resolveCommandByRequest($requestInstance);

		// Add more filters by the command
		$commandInstance->addExtraFilters($this, $requestInstance);

		// Run the pre filters
		$this->executePreFilters($requestInstance, $responseInstance);

		// This request was valid! :-D
		$requestInstance->requestIsValid();

		// Execute the command
		$commandInstance->execute($requestInstance, $responseInstance);

		// Run the pre filters
		$this->executePostFilters($requestInstance, $responseInstance);

		// Flush the response out
		$responseInstance->flushBuffer();
	}

	/**
	 * Add a bootstrap filter
	 *
	 * @param	$filterInstance		A Filterable class
	 * @return	void
	 */
	public function addBootstrapFilter (Filterable $filterInstance) {
		$this->addFilter('bootstrap', $filterInstance);
	}

	/**
	 * Executes all bootstrap filters
	 *
	 * @param	$requestInstance	A Requestable class
	 * @param	$responseInstance	A Responseable class
	 * @return	void
	 */
	public function executeBootstrapFilters (Requestable $requestInstance, Responseable $responseInstance) {
		$this->executeFilters('bootstrap', $requestInstance, $responseInstance);
	}
}

// [EOF]
?>
