<?php
/**
 * A general message handler, this class must be abstract to make the template
 * method pattern working.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
abstract class BaseMessageHandler extends BaseDataHandler {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * "Getter" for a translated last exception as a status code
	 *
	 * @return	$statusCode		Translated status code from last exception
	 */
	protected function getTranslatedStatusFromLastException () {
		// Default is all fine
		$statusCode = BaseHubSystem::MESSAGE_STATUS_CODE_OKAY;

		// Is the last exception not NULL?
		if ($this->getLastException() instanceof FrameworkException) {
			// "Determine" the right status code (may differ from exception to exception)
			$this->debugInstance('lastException=' . $this->getLastException()->__toString() . ',message=' . $this->getLastException()->getMessage() . ' is not finished!');
		} // END - if

		// Return the status code
		return $statusCode;
	}

	/**
	 * Registers an other node with this node by given message data. The
	 * following data must always be present:
	 *
	 * - session-id  (for finding the node's record together with below data)
	 * - external-address (hostname or IP number)
	 * - listen-port (TCP/UDP listen port for inbound connections)
	 *
	 * @param	$messageArray	An array with all minimum message data
	 * @return	void
	 */
	protected function registerNodeByMessageData (array $messageData) {
		// Check if searchData has entries
		assert(count($this->getSearchData()) > 0);

		// Let the DHT facade do the work
		$this->getDhtInstance()->registerNodeByMessageData($messageData, $this);
	}

	/**
	 * Posty-handles data array of the message
	 *
	 * @param	$messageData		An array with message data to handle
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 */
	public function postHandleMessageData (array $messageData, Receivable $packageInstance) {
		/*
		 * Feed hash to miner by handling over the whole array as also the
		 * sender and tags are needed.
		 */
		$packageInstance->feedHashToMiner($messageData);
	}
}

// [EOF]
?>
