<?php
/**
 * A TestUnit source class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class TestUnitSource extends BaseSource implements UnitSource, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$sourceInstance		An instance of a Source class
	 */
	public final static function createTestUnitSource () {
		// Get new instance
		$sourceInstance = new TestUnitSource();

		// Create a RNG instance and set it in this class
		$rngInstance = ObjectFactory::createObjectByConfiguredName('rng_class');
		$sourceInstance->setRngInstance($rngInstance);

		// And also a crypto instance (for our encrypted messages)
		$cryptoInstance = ObjectFactory::createObjectByConfiguredName('crypto_class');
		$sourceInstance->setCryptoInstance($cryptoInstance);

		// Return the prepared instance
		return $sourceInstance;
	}

	/**
	 * Generates an encrypted random message
	 *
	 * @return	$encryptedMessage	The encrypted random message
	 */
	public function generateMessageFromSource () {
		// Get a very secret message by encoding and random string with BASE64
		$secretMessage = base64_encode($this->getRngInstance()->randomString($this->getConfigInstance()->getConfigEntry('random_secret_message_length')));

		// Get a random, secret key
		$secretKey = $this->getRngInstance()->randomString($this->getConfigInstance()->getConfigEntry('test_unit_random_secret_key_length') / 8);

		// Now encrypt the message with our key and a good (strong) cipher
		$encryptedMessage = base64_encode($this->getCryptoInstance()->encryptString($secretMessage, $secretKey));

		// Return it
		return $encryptedMessage;
	}
}

// [EOF]
?>
