<?php
/**
 * A Init cruncher state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2014 Cruncher Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class CruncherInitState extends BaseCruncherState implements Stateable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set state name
		$this->setStateName('init');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$stateInstance	An instance of a Stateable class
	 */
	public final static function createCruncherInitState () {
		// Get new instance
		$stateInstance = new CruncherInitState();

		// Return the prepared instance
		return $stateInstance;
	}

	/**
	 * Executes the state with given Executor instance
	 *
	 * @param	$executorInstance	An instance of a Executor class
	 * @return	void
	 */
	public function executeState (Executor $executorInstance) {
		// Initialize the unit production to maybe become 'virgin' or 'active' if work/test units are there
		$executorInstance->initUnitProduction($this);
	}

	/**
	 * An encrypted message has been generated so we change the state to
	 * 'virgin'.
	 *
	 * @return	void
	 */
	public function encryptedMessageGenerated () {
		// Change the state now to 'virgin'
		CruncherStateFactory::createCruncherStateInstanceByName('virgin');
	}
}

// [EOF]
?>
