<?php
/**
 * An RequestNodeListEntry template engine class for XML templates
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		This template engine does not make use of setTemplateType()
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class XmlRequestNodeListEntryTemplateEngine extends BaseXmlTemplateEngine implements CompileableTemplate, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of the class TemplateEngine and prepares it for usage
	 *
	 * @return	$templateInstance		An instance of TemplateEngine
	 * @throws	BasePathIsEmptyException		If the provided $templateBasePath is empty
	 * @throws	InvalidBasePathStringException	If $templateBasePath is no string
	 * @throws	BasePathIsNoDirectoryException	If $templateBasePath is no
	 *											directory or not found
	 * @throws	BasePathReadProtectedException	If $templateBasePath is
	 *											read-protected
	 */
	public static final function createXmlRequestNodeListEntryTemplateEngine () {
		// Get a new instance
		$templateInstance = new XmlRequestNodeListEntryTemplateEngine();

		// Init template instannce
		$templateInstance->initXmlTemplateEngine('node', 'request_node_list_entry');

		// Return the prepared instance
		return $templateInstance;
	}

	/**
	 * Currently not used
	 *
	 * @param	$resource		XML parser resource (currently ignored)
	 * @param	$characters		Characters to handle
	 * @return	void
	 * @todo	Find something useful with this!
	 */
	public function characterHandler ($resource, $characters) {
		// Trim all spaces away
		$characters = trim($characters);

		// Is this string empty?
		if (empty($characters)) {
			// Then skip it silently
			return;
		} // END - if

		// Assign data with matching variable here
		parent::assignVariable($this->getStackInstance()->getNamed('node_request_node_list_entry'), $characters);
	}

	/**
	 * Getter for cache file (FQFN)
	 *
	 * @return	$fqfn	Full-qualified file name of the menu cache
	 */
	public function getRequestNodeListEntryCacheFqfn () {
		$this->partialStub('Please implement this method.');
	}

	/**
	 * Starts the request-node-list-entry
	 *
	 * @return	void
	 */
	protected function startRequestNodeListEntry () {
		// Push the node name on the stacker
		$this->getStackInstance()->pushNamed('node_request_node_list_entry', 'request-node-list-entry');
	}

	/**
	 * Finishes the request-node-list-entry
	 *
	 * @return	void
	 */
	protected function finishRequestNodeListEntry () {
		// Pop the last entry
		$this->getStackInstance()->popNamed('node_request_node_list_entry');
	}
}

// [EOF]
?>
